Installation
============

To begin using the ``pykoala`` library, follow the steps below:

1. [*Recommended*] Create a dedicated :doc:`python virtual environment <virtual-environment>`.

2. Install PyKOALA using ``pip``:

   .. code-block:: python

       python3 -m pip install pykoala-ifs

   Alternatively, you can :doc:`get a local copy <get-copy>` of the source code and install it manually.

3. Start exploring the library by following the :ref:`user-guide <user-guide>` and running the provided Jupyter tutorials.

Contents
--------

.. toctree::
    :maxdepth: 1

    get-copy
    virtual-environment